==> pipewire-docs-1:1.2.7-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/page_modules.js <==
var page_modules =
[
    [ "Access", "page_module_access.html", null ],
    [ "Adapter", "page_module_adapter.html", null ],
    [ "AVB", "page_module_avb.html", null ],
    [ "Client Device", "page_module_client_device.html", null ],
    [ "Client Node", "page_module_client_node.html", null ],
    [ "Combine Stream", "page_module_combine_stream.html", null ],
    [ "Echo Cancel", "page_module_echo_cancel.html", null ],
    [ "Example Filter", "page_module_example_filter.html", null ],
    [ "Example Sink", "page_module_example_sink.html", null ],
    [ "Example Source", "page_module_example_source.html", null ],
    [ "Fallback Sink", "page_module_fallback_sink.html", null ],
    [ "FFADO firewire audio driver", "page_module_ffado_driver.html", null ],
    [ "Filter-Chain", "page_module_filter_chain.html", null ],
    [ "JACK DBus detect", "page_module_jackdbus_detect.html", null ],
    [ "JACK Tunnel", "page_module_jack_tunnel.html", null ],
    [ "Link Factory", "page_module_link_factory.html", null ],
    [ "Loopback", "page_module_loopback.html", null ],
    [ "Metadata", "page_module_metadata.html", null ],
    [ "Netjack2 driver", "page_module_netjack2_driver.html", null ],
    [ "Netjack2 manager", "page_module_netjack2_manager.html", null ],
    [ "Parametric-Equalizer", "page_module_parametric_equalizer.html", null ],
    [ "Unix Pipe Tunnel", "page_module_pipe_tunnel.html", null ],
    [ "Portal", "page_module_portal.html", null ],
    [ "Profiler", "page_module_profiler.html", null ],
    [ "Protocol Native", "page_module_protocol_native.html", null ],
    [ "Protocol Pulse", "page_module_protocol_pulse.html", null ],
    [ "Protocol Simple", "page_module_protocol_simple.html", null ],
    [ "Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
    [ "AirPlay Sink", "page_module_raop_sink.html", null ],
    [ "RAOP Discover", "page_module_raop_discover.html", null ],
    [ "ROC sink", "page_module_roc_sink.html", null ],
    [ "ROC source", "page_module_roc_source.html", null ],
    [ "SAP Announce and create RTP streams", "page_module_rtp_sap.html", null ],
    [ "RTP sink", "page_module_rtp_sink.html", null ],
    [ "RTP source", "page_module_rtp_source.html", null ],
    [ "RTP session", "page_module_rtp_session.html", null ],
    [ "RT", "page_module_rt.html", null ],
    [ "Session Manager", "page_module_session_manager.html", null ],
    [ "Snapcast Discover", "page_module_snapcast_discover.html", null ],
    [ "VBAN receiver", "page_module_vban_recv.html", null ],
    [ "VBAN sender", "page_module_vban_send.html", null ],
    [ "X11 Bell", "page_module_x11_bell.html", null ],
    [ "Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
];

==> pipewire-docs-1:1.4.9-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/page_modules.js <==
var page_modules =
[
    [ "Access", "page_module_access.html", null ],
    [ "Adapter", "page_module_adapter.html", null ],
    [ "AVB", "page_module_avb.html", null ],
    [ "Client Device", "page_module_client_device.html", null ],
    [ "Client Node", "page_module_client_node.html", null ],
    [ "Combine Stream", "page_module_combine_stream.html", null ],
    [ "Echo Cancel", "page_module_echo_cancel.html", null ],
    [ "Example Filter", "page_module_example_filter.html", null ],
    [ "Example Sink", "page_module_example_sink.html", null ],
    [ "Example Source", "page_module_example_source.html", null ],
    [ "Fallback Sink", "page_module_fallback_sink.html", null ],
    [ "FFADO firewire audio driver", "page_module_ffado_driver.html", null ],
    [ "Filter-Chain", "page_module_filter_chain.html", null ],
    [ "JACK DBus detect", "page_module_jackdbus_detect.html", null ],
    [ "JACK Tunnel", "page_module_jack_tunnel.html", null ],
    [ "Link Factory", "page_module_link_factory.html", null ],
    [ "Loopback", "page_module_loopback.html", null ],
    [ "Metadata", "page_module_metadata.html", null ],
    [ "Netjack2 driver", "page_module_netjack2_driver.html", null ],
    [ "Netjack2 manager", "page_module_netjack2_manager.html", null ],
    [ "Parametric-Equalizer", "page_module_parametric_equalizer.html", null ],
    [ "Unix Pipe Tunnel", "page_module_pipe_tunnel.html", null ],
    [ "Portal", "page_module_portal.html", null ],
    [ "Profiler", "page_module_profiler.html", null ],
    [ "Protocol Native", "page_module_protocol_native.html", null ],
    [ "Protocol Pulse", "page_module_protocol_pulse.html", null ],
    [ "Protocol Simple", "page_module_protocol_simple.html", null ],
    [ "Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
    [ "AirPlay Sink", "page_module_raop_sink.html", null ],
    [ "RAOP Discover", "page_module_raop_discover.html", null ],
    [ "ROC sink", "page_module_roc_sink.html", null ],
    [ "ROC source", "page_module_roc_source.html", null ],
    [ "SAP Announce and create RTP streams", "page_module_rtp_sap.html", null ],
    [ "RTP sink", "page_module_rtp_sink.html", null ],
    [ "RTP source", "page_module_rtp_source.html", null ],
    [ "RTP session", "page_module_rtp_session.html", null ],
    [ "RT", "page_module_rt.html", null ],
    [ "SPA Node", "page_module_spa_node.html", null ],
    [ "SPA Node factory", "page_module_spa_node_factory.html", null ],
    [ "SPA Device", "page_module_spa_device.html", null ],
    [ "SPA Device factory", "page_module_spa_device_factory.html", null ],
    [ "Session Manager", "page_module_session_manager.html", null ],
    [ "Snapcast Discover", "page_module_snapcast_discover.html", null ],
    [ "VBAN receiver", "page_module_vban_recv.html", null ],
    [ "VBAN sender", "page_module_vban_send.html", null ],
    [ "X11 Bell", "page_module_x11_bell.html", null ],
    [ "Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
];
